@@ -3,7 +3,7 @@
 ## @file
 ## @brief Crop image
 ##
-## Requires ImageMagick and exiftool  
+## Requires ImageMagick and exiv2
 ## Crops the image to the size set by the Draw Rectangle menu item
 ##
 
@@ -21,20 +21,20 @@ process_raw ()
 		src_filename=$(ls "$tmpdir/")
 		filename="${src_filename%.*}"
 		extension="${src_filename##*.}"
-		rotation=$(exiftool -Orientation -n "$1" | cut -d':' -f2 | xargs)
+		rotation=$(exiv2 -g Exif.Image.Orientation -Pv "$1")
 		convert "$tmpdir/$src_filename" -crop "$2" "$tmpdir/$filename-crop.$extension"
 
-		exiftool -Orientation="$rotation" -n "$tmpdir/$filename-crop.$extension"
+		exiv2 -M"set Exif.Image.Orientation $rotation" "$tmpdir/$filename-crop.$extension"
 
 		rm "$tmpdir/$src_filename"
 
-		geeqie --remote view:"$tmpdir/$filename-crop.$extension"
+		geeqie --view="$tmpdir/$filename-crop.$extension"
 		res=0
 	else
 		res=1
 	fi
 
-	return $res
+	return "$res"
 }
 
 process_plain ()
@@ -47,26 +47,25 @@ process_plain ()
 	convert "$1" -crop "$2" "$tmpdir/$filename-crop.$extension"
 	if [ $? = 1 ]
 	then
-		zenity --error --title="$title" --text="Cannot process this file format" --width="$width" --window-icon="$window_icon"
+		zenity --error --title="$title" --text="Cannot process this file format" --window-icon="$window_icon"
 	else
-		geeqie --remote view:"$tmpdir/$filename-crop.$extension"
+		geeqie --view="$tmpdir/$filename-crop.$extension"
 	fi
 }
 
 export window_icon="/usr/local/share/pixmaps/geeqie.png"
 export title="Geeqie crop image"
-export width="250"
 
 if [ -x "$(command -v convert)" ]
 then
-	if [ -x "$(command -v exiftool)" ]
+	if [ -x "$(command -v exiv2)" ]
 	then
 
-		coords=$(geeqie --remote --get-rectangle)
+		coords=$(geeqie --get-rectangle)
 
 		if [ -z "$coords" ]
 		then
-			zenity --error --title="$title" --text="Rectangle coordinates have not been set" --width="$width" --window-icon="$window_icon" 2> /dev/null
+			zenity --error --title="$title" --text="Rectangle coordinates have not been set" --window-icon="$window_icon" 2> /dev/null
 			exit 0
 		fi
 
@@ -95,11 +94,11 @@ then
 			fi
 		fi
 	else
-		zenity --info --title="$title" --width="$width" --height=100 --text="Crop image\n\nexiftool is not installed" --title="$title" --window-icon="$window_icon" 2> /dev/null
+		zenity --info --title="$title" --text="Crop image\n\nexiv2 is not installed" --title="$title" --window-icon="$window_icon" 2> /dev/null
 		exit 0
 	fi
 else
-	zenity --info --title="$title" --width="$width" --height=100 --text="Crop image\n\nImageMagick is not installed" --title="$title" --window-icon="$window_icon" 2> /dev/null
+	zenity --info --title="$title" --text="Crop image\n\nImageMagick is not installed" --title="$title" --window-icon="$window_icon" 2> /dev/null
 	exit 0
 fi
 
