@@ -4,10 +4,11 @@
 ## @brief Tethered photography hook script
 ##
 
+# shellcheck disable=SC2154
 if [ "$ACTION" = "download" ]
 then
 	notify-send --expire-time=4000 "$ARGUMENT"  --icon=geeqie
-	geeqie --remote File:"$PWD/$ARGUMENT"
+	geeqie --File="$PWD/$ARGUMENT"
 fi
 
 exit 0
